[−][src]Trait sector_base::api::sector_store::SectorManager
Required methods
fn new_sealed_sector_access(&self) -> Result<String, SectorManagerErr>
provisions a new sealed sector and reports the corresponding access
fn new_staging_sector_access(&self) -> Result<String, SectorManagerErr>
provisions a new staging sector and reports the corresponding access
fn num_unsealed_bytes(&self, access: &str) -> Result<u64, SectorManagerErr>
reports the number of bytes written to an unsealed sector
fn truncate_unsealed(
&self,
access: &str,
size: u64
) -> Result<(), SectorManagerErr>
&self,
access: &str,
size: u64
) -> Result<(), SectorManagerErr>
sets the number of bytes in an unsealed sector identified by access
fn write_and_preprocess(
&self,
access: &str,
data: &mut dyn Read
) -> Result<UnpaddedBytesAmount, SectorManagerErr>
&self,
access: &str,
data: &mut dyn Read
) -> Result<UnpaddedBytesAmount, SectorManagerErr>
writes data to the staging sector identified by access, incrementally preprocessing access
fn delete_staging_sector_access(
&self,
access: &str
) -> Result<(), SectorManagerErr>
&self,
access: &str
) -> Result<(), SectorManagerErr>
fn read_raw(
&self,
access: &str,
start_offset: u64,
num_bytes: UnpaddedBytesAmount
) -> Result<Vec<u8>, SectorManagerErr>
&self,
access: &str,
start_offset: u64,
num_bytes: UnpaddedBytesAmount
) -> Result<Vec<u8>, SectorManagerErr>
Implementors
impl SectorManager for DiskManager[src]
fn new_sealed_sector_access(&self) -> Result<String, SectorManagerErr>[src]
fn new_staging_sector_access(&self) -> Result<String, SectorManagerErr>[src]
fn num_unsealed_bytes(&self, access: &str) -> Result<u64, SectorManagerErr>[src]
fn truncate_unsealed(
&self,
access: &str,
size: u64
) -> Result<(), SectorManagerErr>[src]
&self,
access: &str,
size: u64
) -> Result<(), SectorManagerErr>
fn write_and_preprocess(
&self,
access: &str,
data: &mut dyn Read
) -> Result<UnpaddedBytesAmount, SectorManagerErr>[src]
&self,
access: &str,
data: &mut dyn Read
) -> Result<UnpaddedBytesAmount, SectorManagerErr>
fn delete_staging_sector_access(
&self,
access: &str
) -> Result<(), SectorManagerErr>[src]
&self,
access: &str
) -> Result<(), SectorManagerErr>
fn read_raw(
&self,
access: &str,
start_offset: u64,
num_bytes: UnpaddedBytesAmount
) -> Result<Vec<u8>, SectorManagerErr>[src]
&self,
access: &str,
start_offset: u64,
num_bytes: UnpaddedBytesAmount
) -> Result<Vec<u8>, SectorManagerErr>